@@ -17,11 +17,13 @@ from rest_framework import routers
 
 from . import views
 
-router = routers.DefaultRouter()
-router.register(r'part', views.PartViewSet)
-router.register(r'vendor', views.VendorViewSet)
-router.register(r'vendor_part', views.VendorPartViewSet)
-router.register(r'assembly_item', views.AssemblyItemViewSet)
+router = routers.SimpleRouter()
+router.register(r'part', views.PartViewSet, basename='part')
+router.register(r'vendor', views.VendorViewSet, basename='vendor')
+router.register(r'vendor_part', views.VendorPartViewSet,
+                basename='vendor_part')
+router.register(r'assembly_item', views.AssemblyItemViewSet,
+                basename='assembly_view')
 
 urlpatterns = [
     path('', include(router.urls))
