@@ -1,5 +1,5 @@
 #
-#   Copyright (c) 2014-2016, 2018-2020 eGauge Systems LLC
+#   Copyright (c) 2014-2016, 2018-2021 eGauge Systems LLC
 # 	1644 Conestoga St, Suite 2
 # 	Boulder, CO 80301
 # 	voice: 720-545-9767
@@ -27,6 +27,7 @@ from openpyxl.styles import Font, PatternFill, fills
 from openpyxl.utils import get_column_letter
 
 from epic import perms
+from epic.base import Enum
 from epic.lib import get_stock_summary, get_inventory_summary
 from epic.models import Inventory, Line_Item, Order, Part, Shipment, \
     Vendor, Vendor_Part, Warehouse
@@ -197,7 +198,7 @@ def part_bom_export(request, pk):
 
         # add substitute rows, if any:
         for sub in equiv_parts:
-            if sub == best_part or sub.status == Part.STATUS_PREVIEW:
+            if sub == best_part or sub.status == Enum.STATUS_PREVIEW:
                 continue
             ww.append(str(sub), style, col=3)
             ww.append(sub.mfg, style)
