@@ -1,5 +1,5 @@
 #
-#   Copyright (c) 2014-2019 eGauge Systems LLC
+#   Copyright (c) 2014-2019, 2021 eGauge Systems LLC
 # 	1644 Conestoga St, Suite 2
 # 	Boulder, CO 80301
 # 	voice: 720-545-9767
@@ -29,6 +29,7 @@ from django.utils.html import escape
 from django.contrib.humanize.templatetags.humanize import intcomma
 
 from epic.compat import reverse
+from epic.base import Enum, format_part_number, strchoice
 
 # pylint: disable=arguments-differ
 # pylint: disable=too-many-lines
@@ -36,20 +37,11 @@ from epic.compat import reverse
 PART_PRICE_VALIDATORS = [MinValueValidator(Decimal('0.000001'))]
 CACHE = caches['epic']
 
-def strchoice(choices, val):
-    for key, name in choices:
-        if key == val:
-            return name
-    return val
-
 def part_cost(line_cost, qty):
     if qty <= 0:
         return 0
     return Decimal('%.6f' % (float(line_cost) / qty))
 
-def format_part_number(part):
-    return 'EP%05u' % part
-
 def html_part_link(part):
     """Return an HTML link for PART.  PART may be either a Part object or
     a part number.
@@ -98,44 +90,11 @@ class Datasheet(models.Model):
         for chunk in self.ds_file.chunks():
             md5.update(chunk)
         self.md5sum = md5.hexdigest()
-        super(Datasheet, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     # See signals.datasheet_delete() for deletion cleanup.
 
 class Part(models.Model):
-    MOUNTING_SMD = 0
-    MOUNTING_THD = 1
-    MOUNTING_CHASSIS = 2
-    MOUNTING_FREE = 3
-    MOUNTING_CHOICES = (
-        (MOUNTING_SMD, 'SMD'),
-        (MOUNTING_THD, 'THD'),
-        (MOUNTING_CHASSIS, 'chassis'),
-        (MOUNTING_FREE, 'free')
-    )
-    STATUS_PREVIEW = 0
-    STATUS_ACTIVE = 1
-    STATUS_PREFERRED = 2
-    STATUS_DEPRECATED = 3
-    STATUS_OBSOLETE = 4
-    STATUS_CHOICES = (
-        (STATUS_PREVIEW, 'preview'),
-        (STATUS_ACTIVE, 'active'),
-        (STATUS_PREFERRED, 'preferred'),
-        (STATUS_DEPRECATED, 'deprecated'),
-        (STATUS_OBSOLETE, 'obsolete'),
-    )
-    # deprecated parts are orderable, but preview or obsolete parts
-    # are not:
-    STATUS_ORDERABLE = (STATUS_ACTIVE, STATUS_PREFERRED, STATUS_DEPRECATED)
-    # what modified the part's BOM (assembly-items list) last (user or tool)?:
-    LAST_MOD_TYPE_USER	= 0
-    LAST_MOD_TYPE_TOOL	= 1
-    LAST_MOD_CHOICES = (
-        (LAST_MOD_TYPE_USER, 'user'),
-        (LAST_MOD_TYPE_TOOL, 'tool')
-    )
-
     val = models.CharField(max_length=31, verbose_name='Value', blank=True,
                            default='',
                            help_text='The primary value of the part '
@@ -153,8 +112,8 @@ class Part(models.Model):
                            'part.')
     mfg_pn = models.CharField(max_length=31,
                               verbose_name='Manufacturer\'s Part #')
-    mounting = models.IntegerField(choices=MOUNTING_CHOICES,
-                                   default=MOUNTING_SMD, blank=False,
+    mounting = models.IntegerField(choices=Enum.MOUNTING_CHOICES,
+                                   default=Enum.MOUNTING_SMD, blank=False,
                                    verbose_name='Mounting Type',
                                    help_text='How the part is mounted to a '
                                    'PCB (free if it\'s not mounted at all, '
@@ -179,8 +138,8 @@ class Part(models.Model):
                               'pieces in a reel.')
     lead_time = models.PositiveIntegerField(verbose_name='Lead-time [weeks]',
                                             help_text='Lead-time in weeks.')
-    status = models.IntegerField(choices=STATUS_CHOICES,
-                                 default=STATUS_PREVIEW, blank=False,
+    status = models.IntegerField(choices=Enum.STATUS_CHOICES,
+                                 default=Enum.STATUS_PREVIEW, blank=False,
                                  verbose_name='Life-time Status',
                                  help_text='The life-time status of this '
                                  'part. Parts marked `preview\' and '
@@ -190,8 +149,8 @@ class Part(models.Model):
                                    help_text='List of other parts that are '
                                    '(identical) substitutes for this part.',
                                    on_delete=models.CASCADE)
-    last_bom_mod_type = models.IntegerField(choices=LAST_MOD_CHOICES,
-                                            default=LAST_MOD_TYPE_USER,
+    last_bom_mod_type = models.IntegerField(choices=Enum.LAST_MOD_CHOICES,
+                                            default=Enum.LAST_MOD_TYPE_USER,
                                             blank=False)
     last_bom_mod_name = models.CharField(max_length=31, blank=True, default='',
                                          help_text='Name of entity '
@@ -262,9 +221,9 @@ class Part(models.Model):
             if p == self or not p.is_orderable():
                 continue
 
-            if (p.status == Part.STATUS_PREFERRED) != \
-               (best_part.status == Part.STATUS_PREFERRED):
-                if p.status == Part.STATUS_PREFERRED:
+            if (p.status == Enum.STATUS_PREFERRED) != \
+               (best_part.status == Enum.STATUS_PREFERRED):
+                if p.status == Enum.STATUS_PREFERRED:
                     best_part = p
                 continue
 
@@ -283,12 +242,12 @@ class Part(models.Model):
         vps = Vendor_Part.objects.filter(part_id=self.id) \
                                  .order_by('price')
         for vp in vps:
-            if vp.status in Part.STATUS_ORDERABLE:
+            if vp.status in Enum.STATUS_ORDERABLE:
                 return vp.vendor
         return None
 
     def is_orderable(self):
-        return self.status in Part.STATUS_ORDERABLE
+        return self.status in Enum.STATUS_ORDERABLE
 
     def assembly_items(self):
         return Assembly_Item.objects.filter(assy_id=self.id)
@@ -381,7 +340,7 @@ class Part(models.Model):
         return best_vp_any
 
     def strstatus(self):
-        return strchoice(Part.STATUS_CHOICES, self.status)
+        return strchoice(Enum.STATUS_CHOICES, self.status)
 
     def choice_label(self):
         return '%s: %s %s' % (self, self.mfg, self.mfg_pn)
@@ -423,8 +382,8 @@ class Vendor_Part(models.Model):
                                  verbose_name='Vendor\'s Part #')
     price = models.DecimalField(max_digits=10, decimal_places=6,
                                 validators=PART_PRICE_VALIDATORS)
-    status = models.IntegerField(choices=Part.STATUS_CHOICES,
-                                 default=Part.STATUS_ACTIVE, blank=False,
+    status = models.IntegerField(choices=Enum.STATUS_CHOICES,
+                                 default=Enum.STATUS_ACTIVE, blank=False,
                                  verbose_name='Life-time Status',
                                  help_text='The life-time status of this '
                                  'vendor part.')
@@ -452,10 +411,10 @@ class Vendor_Part(models.Model):
             (url, self.vendor_pn)
 
     def strstatus(self):
-        return strchoice(Part.STATUS_CHOICES, self.status)
+        return strchoice(Enum.STATUS_CHOICES, self.status)
 
     def is_orderable(self):
-        return self.status in Part.STATUS_ORDERABLE
+        return self.status in Enum.STATUS_ORDERABLE
 
     @staticmethod
     def get(part_id, vendor_id):
@@ -698,10 +657,10 @@ class Transaction(models.Model):
         else:
             return
 
-        status = Order.STATUS_CLOSED
+        status = Enum.TXTN_STATUS_CLOSED
         for line_item in Line_Item.objects.filter(txtn_id=order.id):
             if line_item.qty_remaining_to_ship() > 0:
-                status = Order.STATUS_OPEN
+                status = Enum.TXTN_STATUS_OPEN
                 break
 
         if status != order.status:
@@ -782,18 +741,12 @@ class Transaction(models.Model):
         return 'Transaction&nbsp;%d' % (self.id)
 
 class Order(Transaction):
-    STATUS_OPEN = 0
-    STATUS_CLOSED = 1
-    STATUS_CHOICES = (
-        (STATUS_OPEN,	'open'),
-        (STATUS_CLOSED,	'closed'),
-    )
     expected_arrival_date = models.DateField(verbose_name='Expected Arrival '
                                              'Date', help_text='Date when '
                                              'the order is expected to '
                                              'arrive.')
-    status = models.IntegerField(choices=STATUS_CHOICES,
-                                 default=STATUS_OPEN, blank=False,
+    status = models.IntegerField(choices=Enum.TXTN_STATUS_CHOICES,
+                                 default=Enum.TXTN_STATUS_OPEN, blank=False,
                                  verbose_name='Order Status')
     vendor = models.ForeignKey(Vendor, help_text='The name of the '
                                'vendor (distributor) where the order '
@@ -808,10 +761,10 @@ class Order(Transaction):
                    .values_list('line_cost', flat=True))
 
     def is_open(self):
-        return self.status == Order.STATUS_OPEN
+        return self.status == Enum.TXTN_STATUS_OPEN
 
     def days_until_past_due(self):
-        if self.status != Order.STATUS_OPEN:
+        if self.status != Enum.TXTN_STATUS_OPEN:
             return None
         return (self.expected_arrival_date - date.today()).days
 
