@@ -89,8 +89,8 @@ from django.conf import settings as cfg
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
 
-from epic.models import Part, format_part_number, Assembly_Item, strchoice, \
-    Vendor
+from epic.models import Part, Assembly_Item, Vendor
+from epic.base import Enum, format_part_number, strchoice
 
 MY_TOOL_NAME = 'kicad-to-epic-bom'
 
@@ -141,7 +141,7 @@ def quote(string):
 def save_assembly(assembly_part, bom):
     created = assembly_part.id is None
 
-    assembly_part.last_bom_mod_type = Part.LAST_MOD_TYPE_TOOL
+    assembly_part.last_bom_mod_type = Enum.LAST_MOD_TYPE_TOOL
     assembly_part.last_bom_mod_name = MY_TOOL_NAME
     assembly_part.save()
 
@@ -196,8 +196,8 @@ def legacy_update_comp(comp):
                   file=sys.stderr)
             return False
         if part.footprint is None or part.footprint == '':
-            if part.mounting != Part.MOUNTING_CHASSIS \
-               and part.mounting != Part.MOUNTING_FREE:
+            if part.mounting != Enum.MOUNTING_CHASSIS \
+               and part.mounting != Enum.MOUNTING_FREE:
                 print('%s: warn: EPIC part %s has no footprint defined' %
                       (MY_TOOL_NAME, format_part_number(part.id)),
                       file=sys.stderr)
@@ -292,7 +292,7 @@ def modern_update_symbol(symbol, updated_syms):
         footprint = part.footprint
         if not footprint:
             footprint = ''
-            if part.mounting not in [Part.MOUNTING_CHASSIS, Part.MOUNTING_FREE]:
+            if part.mounting not in [Enum.MOUNTING_CHASSIS, Enum.MOUNTING_FREE]:
                 print('%s: warn: EPIC part %s has no footprint defined' %
                       (MY_TOOL_NAME, format_part_number(part.id)),
                       file=sys.stderr)
@@ -570,7 +570,7 @@ def main():
             if title_block is not None:
                 if revision == '':
                     rev = title_block.find('rev')
-                    if rev is not None:
+                    if rev and rev.text:
                         revision = '-rev' + rev.text.lstrip().rstrip()
                 sources.append(title_block.find('source').text)
 
@@ -591,11 +591,11 @@ def main():
     qs = Part.objects.filter(mfg=manufacturer).filter(mfg_pn=assembly_name)
     if qs.exists():
         assembly_part = qs[0]
-        if assembly_part.last_bom_mod_type != Part.LAST_MOD_TYPE_TOOL \
+        if assembly_part.last_bom_mod_type != Enum.LAST_MOD_TYPE_TOOL \
            or assembly_part.last_bom_mod_name != MY_TOOL_NAME:
             print('%s: info: part %s %s was last modified by %s %s' %
                   (MY_TOOL_NAME, manufacturer, assembly_name,
-                   strchoice(Part.LAST_MOD_CHOICES,
+                   strchoice(Enum.LAST_MOD_CHOICES,
                              assembly_part.last_bom_mod_type),
                    assembly_part.last_bom_mod_name), file=sys.stderr)
             if args.force_overwrite:
@@ -614,10 +614,10 @@ def main():
             desc += (', ' + flavor + ' flavor')
         assembly_part = Part(descr=desc,
                              mfg=manufacturer, mfg_pn=assembly_name,
-                             mounting=Part.MOUNTING_CHASSIS,
+                             mounting=Enum.MOUNTING_CHASSIS,
                              target_price=1000,
                              overage=1, spq=1, lead_time=4,
-                             status=Part.STATUS_PREVIEW)
+                             status=Enum.STATUS_PREVIEW)
 
     ep_pat = re.compile(r'EP(-(.*))?')
     inst_pat = re.compile(r'Installation(-(.*))?')
