@@ -1,5 +1,5 @@
 #
-#   Copyright (c) 2014-2015, 2018 eGauge Systems LLC
+#   Copyright (c) 2014-2015, 2018, 2021 eGauge Systems LLC
 # 	1644 Conestoga St, Suite 2
 # 	Boulder, CO 80301
 # 	voice: 720-545-9767
@@ -11,6 +11,7 @@
 #   copied, modified, or disclosed without any prior and written
 #   permission from eGauge Systems LLC.
 #
+# pylint: disable=invalid-name
 '''Unit tests.  Run, e.g., from epic-sample with:
 
 	python3 manage.py test epic.tests
@@ -29,6 +30,7 @@ from django.contrib.auth import models as auth_models
 
 import epic
 from epic import perms
+from epic.base import Enum
 from epic.compat import reverse
 from epic.lib import get_stock
 from epic.models import Assembly_Item, Delta, Inventory, Line_Item, Order, \
@@ -65,8 +67,8 @@ class URL_Iterator:
 
 def create_part(pk):
     return Part(pk=pk, mfg='mfg', mfg_pn='mfg_pn%d' % pk,
-                mounting=Part.MOUNTING_SMD, target_price=1, overage=0,
-                spq=1, status=Part.STATUS_ACTIVE, lead_time=9)
+                mounting=Enum.MOUNTING_SMD, target_price=1, overage=0,
+                spq=1, status=Enum.STATUS_ACTIVE, lead_time=9)
 
 def create_warehouse(pk, name):
     return Warehouse(pk=pk, name=name)
@@ -83,7 +85,7 @@ def create_order(pk, vendor_id, warehouse_id):
     then = now + timedelta(days=30)
     return Order(pk=pk, ts=now, warehouse_id=warehouse_id,
                  expected_arrival_date=then,
-                 status=Order.STATUS_OPEN, vendor_id=vendor_id)
+                 status=Enum.TXTN_STATUS_OPEN, vendor_id=vendor_id)
 
 def create_ship(pk, order_id, warehouse_id, tracking='1Z9AA10123456784',
                 cost_freight=0, cost_other=0, cost_discount=0):
@@ -295,16 +297,16 @@ class Stock_Cache_Tests(TestCase):
 class Part_Method_Tests(TestCase):
 
     def test_is_orderable(self):
-        p = Part(status=Part.STATUS_PREVIEW)
+        p = Part(status=Enum.STATUS_PREVIEW)
         self.assertEqual(p.is_orderable(), False)
 
-        p = Part(status=Part.STATUS_ACTIVE)
+        p = Part(status=Enum.STATUS_ACTIVE)
         self.assertEqual(p.is_orderable(), True)
 
-        p = Part(status=Part.STATUS_DEPRECATED)
+        p = Part(status=Enum.STATUS_DEPRECATED)
         self.assertEqual(p.is_orderable(), True)
 
-        p = Part(status=Part.STATUS_OBSOLETE)
+        p = Part(status=Enum.STATUS_OBSOLETE)
         self.assertEqual(p.is_orderable(), False)
 
     def test_equivalent_parts(self):
@@ -340,11 +342,11 @@ class Part_Method_Tests(TestCase):
 
     def test_best_parts(self):
         p1 = create_part(1)
-        p1.status = Part.STATUS_PREFERRED
+        p1.status = Enum.STATUS_PREFERRED
         p1.save()
 
         p2 = create_part(2)
-        p2.status = Part.STATUS_PREFERRED
+        p2.status = Enum.STATUS_PREFERRED
         p2.substitute = p1
         p2.save()
 
@@ -359,13 +361,13 @@ class Part_Method_Tests(TestCase):
         self.assertEqual(p1.best_part(), p2)
         self.assertEqual(p2.best_part(), p2)
 
-        p2.status = Part.STATUS_ACTIVE
+        p2.status = Enum.STATUS_ACTIVE
         p2.save()
         # p1 is preferred, even though it's higher price
         self.assertEqual(p1.best_part(), p1)
         self.assertEqual(p2.best_part(), p1)
 
-        p1.status = Part.STATUS_ACTIVE
+        p1.status = Enum.STATUS_ACTIVE
         p1.save()
         # now p2 should win again due to lower price:
         self.assertEqual(p1.best_part(), p2)
@@ -807,7 +809,7 @@ class Access_Tests(TestCase):
         l.save()
 
         # order should be open now
-        self.assertEqual(o.status, Order.STATUS_OPEN)
+        self.assertEqual(o.status, Enum.TXTN_STATUS_OPEN)
 
         # create two shipments that should complete the order:
         s = create_ship(2, o.pk, 1, '1Z1345', 1.23, 2.34, 3.45)
@@ -824,7 +826,7 @@ class Access_Tests(TestCase):
 
         # order should be closed now:
         o = Order.objects.get(pk=4)
-        self.assertEqual(o.status, Order.STATUS_CLOSED)
+        self.assertEqual(o.status, Enum.TXTN_STATUS_CLOSED)
 
         # delete the first shipment:
         url = reverse('epic:ship_delete', kwargs={'pk':2})
@@ -833,4 +835,4 @@ class Access_Tests(TestCase):
 
         # order should be open again:
         o = Order.objects.get(pk=4)
-        self.assertEqual(o.status, Order.STATUS_OPEN)
+        self.assertEqual(o.status, Enum.TXTN_STATUS_OPEN)
